@@ -30,6 +30,9 @@ download_assessment_internal <- memoise::memoise(function(assessment_id) {
                       V7 = character(0),
                       V8 = character(0),
                       V9 = character(0))
+  class(empty) <- c("tbl_df",
+                    "tbl",
+                    "data.frame")
 
   if (assessment_id == -40000){
     return(invisible(empty))
@@ -41,11 +44,16 @@ download_assessment_internal <- memoise::memoise(function(assessment_id) {
   ua <-
     httr::user_agent("https://github.com/equitable-equations/fqar")
 
-  assessment_get <- tryCatch(httr::GET(assessment_address, ua),
+  assessment_get <- tryCatch(httr::GET(assessment_address,
+                                       ua,
+                                       timeout(2)),
                              error = function(e){
-                               message("Unable to connect. Please check internet connection.")
+                               message("No response from universalFQA.org. Please check internet connection.")
+                               character(0)},
+                             message = function(m){
+                               message("No response from universalFQA.org. Please check internet connection.")
                                character(0)
-                             }
+                               }
   )
 
   cl <- class(assessment_get)
